#
# spec file for package lzip
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2008-2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lzip
Version:        1.25
Release:        1.3
Summary:        Lossless Data Compressor based on the LZMA Algorithm
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Compression
URL:            https://www.nongnu.org/lzip/lzip.html
Source:         https://download.savannah.gnu.org/releases/lzip/%name-%version.tar.gz
Source2:        https://download.savannah.gnu.org/releases/lzip/%name-%version.tar.gz.sig
Source3:        %name.keyring
BuildRequires:  gcc-c++
PreReq:         %install_info_prereq

%description
Lzip is a lossless data compressor based on the LZMA algorithm, with very safe
integrity checking and a user interface almost identical to the one of
bzip2. Lzip is only a data compressor, not an archiver. It has no facilities
for multiple files, encryption, or archive-splitting, but, in the Unix
tradition, relies instead on separate external utilities such as GNU Tar for
these tasks.

%prep
%autosetup -p1

%build
# not autoconf:
mkdir build
pushd build/
../configure --prefix="%_prefix" --bindir="%_bindir" --datadir="%_datadir" \
	--infodir="%_infodir" --mandir="%_mandir" --sysconfdir="%_sysconfdir" \
	CC="%__cc" CFLAGS="%optflags" CXX="%__cxx" CXXFLAGS="%optflags"
%make_build
popd

%install
pushd build/
%make_install
popd

%check
pushd build/
%make_build check
popd

%post
%install_info --info-dir="%_infodir" "%_infodir/lzip.info%ext_info"

%postun
%install_info_delete --info-dir="%_infodir" "%_infodir/lzip.info%ext_info"

%files
%doc ChangeLog README
%license COPYING
%_bindir/lzip
%_infodir/lzip.info%ext_info
%_mandir/man1/lzip.1%ext_man

%changelog
* Sun Jan 19 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.25
  * lzip now exits with error status 2 if any empty member is found
    in a multimember file.
  * lzip now exits with error status 2 if the first byte of the
    LZMA stream is not 0.
  * Options `--empty-error` and `--marking-error` have been
    removed.
* Thu Feb  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.24
  * Added the command-line switches --empty-error and
  - -marking-error
  * The option -o/--output now preserves dates, permissions, and
    ownership of the file when (de)compressing exactly one file.
  * The option -o/--output now creates missing intermediate
    directories when writing to a file.
* Sun Feb 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.23
  * Decompression time has been reduced by 5-12%% depending on the
    file.
  * In case of error in a numerical argument to a command line
    option, lzip now shows the name of the option and the range
    of valid values.
* Tue Jan 19 2021 Dirk Müller <dmueller@suse.com>
- update to 1.22:
  * Lzip now reports an error if a file name is empty (lzip -t "").
  * Option '-o, --output' now behaves like '-c, --stdout', but
    sending the output unconditionally to a file instead of to
    standard output.
  * Lzip now does not even open the output file if the input file
    is a terminal.
  * Lzip can now be built, tested, and installed on systems
    lacking a 'make' program. (Feature suggested by Mohammad
    Akhlaghi).
  * The words 'decompressed' and 'compressed' have been replaced
    with the shorter 'out' and 'in' in the verbose output when
    decompressing or testing.
  * Option '--list' now reports corruption or truncation of the
    last header in a multimenber file specifically instead of
    showing the generic message "Last member in input file is
    truncated or corrupt."
  * The commands needed to extract files from a tar.lz archive
    have been documented in the manual, in the output of '--help',
    and in the man page.
  * Plzip and tarlz are mentioned in the manual as alternatives for
    multiprocessors.
  * Several fixes and improvements have been made to the manual.
* Sun Jan 13 2019 seanlew@opensuse.org
- Update to new upstream release 1.21
  * Errors are now also checked when closing the input file
  * The descritions in the man pages are improved
  * Config script now accepts appending CXXFLAGS options
* Fri Dec 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.21~rc1
  * Detection of forbidden combinations of characters in trailing
    data has been improved.
* Mon Mar  5 2018 jengelh@inai.de
- Update to new upstream release 1.20
  * The option "--loose-trailing" has been added.
  * The test used by clzip to discriminate trailing data from a
    corrupt header in multimember or concatenated files has been
    improved to a Hamming distance of 3.
  * The "-S" option now keeps input files unchanged.
* Tue Jan 23 2018 avindra@opensuse.org
- Update to version 1.19
  * The option '-l, --list' has been ported from lziprecover.
  * Don't allow mixing different operations (-d, -l or -t).
  * Compression time of option '-0' has been slightly reduced.
  * Decompression time has been reduced by 2%%.
  * main.cc: Continue testing if any input file is a terminal.
  * main.cc: Show trailing data in both hexadecimal and ASCII.
  * encoder.cc (Matchfinder_base): Verify size passed to new.
  * file_index.cc: Improve detection of bad dict and trailing data.
  * lzip.h: Unified messages for bad magic, trailing data, etc.
- switch to https in source urls
* Sun Jun  5 2016 mpluskal@suse.com
- Update to version 1.18:
  * main.cc: Added new option '-a, --trailing-error'.
  * Decompression time has been reduced by 2%%.
  * decoder.cc (verify_trailer): Removed test of final code.
  * main.cc (main): Delete '--output' file if infd is a terminal.
  * main.cc (main): Don't use stdin more than once.
  * Removed decompression support for version 0 files.
  * lzip.texi: Added chapter 'Trailing data'.
  * configure: Avoid warning on some shells when testing for g++.
  * Makefile.in: Detect the existence of install-info.
  * testsuite/check.sh: A POSIX shell is required to run the tests.
  * testsuite/check.sh: Don't check error messages.
* Thu Aug  6 2015 jengelh@inai.de
- Update to new upstream release 1.17
  * The compression code has been reorganized to ease the porting of
  the fast encoder to clzip and lzlib.
  * The new chapter "Quality assurance" has been added to the manual.
* Wed Oct  1 2014 jengelh@inai.de
- Update to new upstream release 1.16
  * Compression ratio of option -9 has been slightly increased.
  * Compression time has been reduced by 4%%.
  * `lzip -0` is now comparable in compression speed and ratio to
  `gzip -6` (gzip's default compression level).
  * Copying of file dates, permissions, and ownership now behaves
  like `cp -p`. (If the user ID or the group ID cannot be
  duplicated, the file permission bits S_ISUID and S_ISGID are
  cleared).
  * The license has been changed to GPL version 2 or later.
* Fri Oct  4 2013 jengelh@inai.de
- Update to new upstream release 1.15
  * This release shows the progress of compression at verbosity
  level 2 (-vv).
  * The chapter "Stream format" and the appendix "Reference source
  code" have been added to the manual.
* Mon Apr  1 2013 pascal.bleser@opensuse.org
- update to 1.14:
  * Multi-step trials have been implemented
  * Compression ratio has been slightly increased
  * Compression time has been reduced by 5%%
  * Decompression time has been reduced by 12%%
* Tue Sep  4 2012 cfarrell@suse.com
- license update: GPL-3.0+
  Use SPDX format (http://www.spdx.org/licenses)
* Sun Mar 18 2012 pascal.bleser@opensuse.org
- update to 1.13:
  * lziprecover has been moved to its own package
  * inability to change output file attributes has been downgraded from error
    to warning
  * compression time of option "-0" has been reduced by 2%%
  * a reorganization of the compression code has been made
  * a small change has been made in the "--help" output and man page
  * quote characters in messages have been changed as advised by GNU Coding
    Standards
* Fri May 13 2011 pascal.bleser@opensuse.org
- update to 1.12:
  * the option "-F, --recompress", which forces recompression of files whose
    name already has the ".lz" or ".tlz" suffix, has been added
  * for large values of "--match-length", the compression ratio has been
    slightly increased, and compression time has been reduced by up to 6%%
  * the compression time of the option "-0" has been reduced by 2%%
  * this release will print only one status line for each multi-member file
    when only one "-v" is specified
  * it will print up to 6 bytes of trailing garbage when "-vvvv" is specified
  * it does not show the message "and `--stdout' was not specified" for file
    types that can't be read (directories, etc)
* Mon Sep 27 2010 pascal.bleser@opensuse.org
- update to 1.11:
  * match length limit set by options -1 to -8 has been reduced to extend the
    range of use towards gzip; lower numbers now compress less but faster
  * also, a "-0" option as fast as "gzip -9" has been added
  * the compression of option -9 has been slightly increased
  * the "--merge" option, which tries to produce a correct file by merging the
    good parts of two or more damaged copies, has been added to lziprecover:
    for large files with small errors, the probability of producing a correct
    file approaches 100 percent
  * lziprecover is now able to repair any 1-byte error in the lzma stream of
    damaged lzip files
* Sat Apr 10 2010 pascal.bleser@opensuse.org
- update to 1.10:
  * a file specified with the "-o" option is now created with write permission
    for all if umask allows it, and it is deleted if lzip is interrupted by the
    user
  * the dictionary size for the options -2, -3, -4, and -8 has been changed to
    improve linearity of compressed sizes
* Tue Jan 19 2010 pascal.bleser@opensuse.org
- update to 1.9:
  * Lzip now returns at least 1 if closing stdout fails
  * lintian warnings in Debian about man pages have been fixed
  * the "COPYING" file is no longer used as data for testing
* Fri Sep  4 2009 pascal.bleser@opensuse.org
- update to 1.8:
  * compression time has been reduced by 4%%
- changes from 1.7:
  * lzdiff and lzgrep have been renamed to zdiff and zgrep and moved to the new
    package zutils (http://freshmeat.net/projects/zutils)
  * compilation warnings on systems where uint32_t... != unsigned int have been
    fixed.
* Tue Jun 23 2009 pascal.bleser@opensuse.org
- update to 1.6:
  * decompression time has been reduced by 17%%
  * decompression support for the "Sync Flush marker" from lzlib has been added
  * man pages for lzdiff, lzgrep, and lziprecover have been added to the
    distribution
  * memory use has been reduced to 9x if the input file is smaller than
    dictionary size limit
  * flush calls have been added to decompressor to allow partial recovery of
    the uncompressed data when decompressing a corrupt file
  * the dependence of "--test" on the existence of "/dev/null" has been removed
  * some "bashisms" have been removed from lzdiff and lzgrep
* Wed Apr 15 2009 pascal.bleser@opensuse.org
- update to 1.5
* Mon Dec 22 2008 guru@unixtech.be
- update to 1.3
* Tue Nov 18 2008 guru@unixtech.be
- update to 1.1:
  * the short name of the option "--dictionary-size" has been changed to "-s"
  * the short name of the option "--match-length" has been changed to "-m"
  * some user messages have been improved
* Tue Oct 14 2008 guru@unixtech.be
- update to 1.0:
  * small changes have been made to the documentation and user messages
* Wed Oct  1 2008 guru@unixtech.be
- update to 0.5:
  * decompression speed has been improved by 1%%
* Wed Sep 24 2008 guru@unixtech.be
- update to 0.4:
  * this release regains the compression ratio of version 0.2 with a speed
    that is a 5%% faster
  * a compilation problem on systems where "size_t" is different from
    "unsigned int" has been fixed
* Mon Sep 15 2008 guru@unixtech.be
- new package
